#MSUB -r moistc_land-hist
#MSUB -o moistc_land-hist.out_%I
#MSUB -e moistc_land-hist.out_%I
#MSUB -n 1
#MSUB -T 36000
#MSUB -q xlarge
#MSUB -c 8
#MSUB -Q normal
#MSUB -A gen0239
#MSUB -m store,work,scratch
##MSUB -A ls3cmip6 
set +vx

# Script to create nudging file for soil moisture. 
# This extracts moistc variable from sechiba_out_2.nc output files from a previsous simulation.
# The moistc variable is separated into 3 variables depending on the soiltiles moistc_1, 
# moistc_2 and moistc_3.
#
# $HeadURL$
# $Date$
# $Revision$
#######################################################################################################################
date
JobName=CM61-LR-land-hist-02
mkdir run_moistc_${JobName}
cd run_moistc_${JobName}

echo Start
# 1. Path to simulation land-hist
#    Note: the files are daily output frequency even if the folder and file name contain HF
simulpath=/ccc/store/cont003/gencmip6/p529vui/IGCM_OUT//PROD/land-hist/CM61-LR-land-hist-02/SRF/Output/HF

# 2. Extract moistc
echo Extract variable moistc from yearly files
# float moistc(time_counter, soiltyp, solay, lat, lon)
year=1850
lastyear=2014
while [ ${year} -le ${lastyear} ] ; do
  pack=${year}0101_${year}1231
  echo Treat file ${simulpath}/${JobName}_${pack}_HF_sechiba_out_2.nc

  # Extract the variable moistc 
  ncks -v moistc ${simulpath}/${JobName}_${pack}_HF_sechiba_out_2.nc moistc_${year}_sechiba_out_2.nc

  # Separate into variables per soiltile
  ncks -d soiltyp,0,0 moistc_${year}_sechiba_out_2.nc moistc1_${year}_sechiba_out_2.nc
  ncks -d soiltyp,1,1 moistc_${year}_sechiba_out_2.nc moistc2_${year}_sechiba_out_2.nc
  ncks -d soiltyp,2,2 moistc_${year}_sechiba_out_2.nc moistc3_${year}_sechiba_out_2.nc

  ncrename -v moistc,moistc_1 moistc1_${year}_sechiba_out_2.nc
  ncrename -v moistc,moistc_2 moistc2_${year}_sechiba_out_2.nc
  ncrename -v moistc,moistc_3 moistc3_${year}_sechiba_out_2.nc

  # Remove dimension soiltyp (which is now 1) by averaging over the dimension. Put all variables in the same file.
  for soiltyp in 1 2 3 ; do
    ncwa -A -a soiltyp  moistc${soiltyp}_${year}_sechiba_out_2.nc moistc_${year}.nc 
  done
  ncatted -a long_name,moistc_1,m,c,"Soil Moisture profile for soil tile 1" moistc_${year}.nc 
  ncatted -a long_name,moistc_2,m,c,"Soil Moisture profile for soil tile 2" moistc_${year}.nc 
  ncatted -a long_name,moistc_3,m,c,"Soil Moisture profile for soil tile 3" moistc_${year}.nc 

  let year=${year}+1

done


echo End

